@@ -32,6 +32,9 @@ EVT_EXT_SETREGEX = wx.PyEventBinder(myEVT_EXT_SETREGEX)
 myEVT_EXT_GETREGEX = wx.NewEventType()
 EVT_EXT_GETREGEX = wx.PyEventBinder(myEVT_EXT_GETREGEX)
 
+myEVT_EXT_QUIT = wx.NewEventType()
+EVT_EXT_QUIT = wx.PyEventBinder(myEVT_EXT_QUIT)
+
 class SetTextEvent(wx.PyEvent):
     """
     Custom wxPython event, needed to communicate a "Set" action
@@ -49,6 +52,13 @@ class GetTextEvent(wx.PyEvent):
     def __init__(self, evtType):
         wx.PyEvent.__init__(self, eventType=evtType)
         self.text = ''
+        
+class QuitEvent(wx.PyEvent):
+    """
+    Custom wxPython event; quits XML-RPC server upon reception.
+    """
+    def __init__(self):
+        wx.PyEvent.__init__(self, eventType=EVT_EXT_QUIT)
 
 class PyrebAPI:
     """
@@ -100,6 +110,12 @@ class PyrebAPI:
         evt = GetTextEvent(myEVT_EXT_GETREGEX)
         self.Wnd.GetEventHandler().ProcessEvent(evt)
         return evt.text
+    
+    def Quit(self):
+        print "QuitEvent"
+        evt = QuitEvent()
+        self.Wnd.GetEventHandler().ProcessEvent(evt)
+        return
 
 def handlerSetup(handler, API):
     handler.register_introspection_functions()
@@ -107,6 +123,7 @@ def handlerSetup(handler, API):
     handler.register_function(API.getText, "Pyreb.getText")
     handler.register_function(API.setRegex, "Pyreb.setRegex")
     handler.register_function(API.getRegex, "Pyreb.getRegex")
+    #~ handler.register_function(API.Quit, "Pyreb.Quit")
     
 class PyrebXMLRPCServer(threading.Thread):
     """
